==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+51"/>
        <source>Rulers and Scrollbars</source>
        <translation>Los reglas y las barras de desplazamiento</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Mostrar reglas</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Mostrar las barras de desplazamiento</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Mostrar retículo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Mostrar retículo grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Rejilla</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Escalar rejilla automáticamente</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Rejilla líneas continuas</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Espacio mínimo en la rejilla (px):</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">Escalar rejilla meta automáticamente</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Origin</source>
        <translation>Origen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Mostrar retículo grande</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Auto Zoom</source>
        <translation>Zoom automático</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Margen (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Auto zoom después de la carga</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Ajuste de color</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Auto corregir los colores blanco y negro</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Umbral para la claridad del color:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Tipos de línea</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Usar automáticamente los tipos de línea base de la pantalla de visualización del modelo</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Escalar los patrones de línea basado en el grosor de línea</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Escala del patrón de grosor de 0.00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Visualización y rendimiento</translation>
    </message>
    <message>
        <location line="+146"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Mostrar las entidades con más de N guiones como contínua:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Paso ángulo mínimo para la prestación de arcos (grados):</translation>
    </message>
    <message>
        <location line="+144"/>
        <source>Use full resolution for Retina display</source>
        <translation>Utilice la resolución completa de la pantalla Retina</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Antialiasing activado por defecto</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Número máximo de puntos de referencia muestran:</translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Tiempo de espera para la representación rayado:</translation>
    </message>
    <message>
        <source>Antialiasing on by default</source>
        <translation type="vanished">Antialiasing activado por defecto</translation>
    </message>
    <message>
        <source>Display entities with N dashes as continuous:</source>
        <translation type="obsolete">Mostrar entidades con guiones N como contínua:</translation>
    </message>
    <message>
        <location line="-342"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Usar automáticamente los tipos de línea base de la pantalla de visualización del modelo</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="obsolete">Ajusta automáticamente los tipos de línea</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Rendimiento</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number of preview entities:</source>
        <translation>Número de entidades previsualizadas:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Mostrar límite para el texto (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Mostrar arcos como las líneas por debajo de este ángulo (grados):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Mostrar límite para el texto:</translation>
    </message>
    <message>
        <location line="+339"/>
        <source>Selection</source>
        <translation>Selección</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Selección persistente</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <source>Show rulers</source>
        <translation type="obsolete">Mostrar reglas</translation>
    </message>
    <message>
        <source>Show scrollbars</source>
        <translation type="obsolete">Mostrar las barras de desplazamiento</translation>
    </message>
    <message>
        <source>Show crosshairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar retículo</translation>
    </message>
    <message>
        <source>Show large crosshairs</source>
        <translation type="obsolete">Mostrar retículo grande</translation>
    </message>
    <message>
        <source>Rulers and Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Los reglas y las barras de desplazamiento</translation>
    </message>
    <message>
        <source>Show Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar las barras de desplazamiento</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translatorcomment>--google--
&amp;Resaltar entidades bajo el cursor
Resaltar entidades bajo el cursor
Coordenadas del mapa en la posición del ratón</translatorcomment>
        <translation type="obsolete">Cursor</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Rejilla</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Escalar rejilla automáticamente</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Rejilla líneas continuas</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Espacio mínimo en la rejilla (px):</translation>
    </message>
    <message>
        <source>Auto Zoom</source>
        <translation type="obsolete">Zoom automático</translation>
    </message>
    <message>
        <source>Color Adjustment</source>
        <translation type="obsolete">Ajuste de color</translation>
    </message>
    <message>
        <source>Prevent white on white / black on black display</source>
        <translation type="obsolete">Auto corregir los colores blanco y negro</translation>
    </message>
    <message>
        <source>Color lightness threshold:</source>
        <translation type="obsolete">Umbral para la claridad del color:</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="obsolete">Rendimiento</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Mostrar límite para el texto:</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translatorcomment>--exact match--
--file: sketch_es.po--
Extensión
Auto zoom</translatorcomment>
        <translation type="obsolete">Nivel de acercamiento</translation>
    </message>
    <message>
        <source>Margin (px):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Margen (px):</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Previsualización</translation>
    </message>
    <message>
        <source>Number of preview entities:</source>
        <translation type="obsolete">Número de entidades previsualizadas:</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crea un nuevo bloque de entidades existentes
Quita la selección a todas las entidades
Deselecciona todas las entidades
Deseleccionar en&amp;tidades cruzadas</translatorcomment>
        <translation type="obsolete">Entidades</translation>
    </message>
    <message>
        <source>Auto correct black and white colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Auto corregir los colores blanco y negro</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation type="obsolete">Selección</translation>
    </message>
    <message>
        <source>Persistent Selection</source>
        <translatorcomment>--google--
Selecciones &amp;persisitentes
Selecciones persisitentes</translatorcomment>
        <translation type="obsolete">Selección persistente</translation>
    </message>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_es.ts--
Ver gráficos</translatorcomment>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+51"/>
        <source>Rulers and Scrollbars</source>
        <translation>Los reglas y las barras de desplazamiento</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Mostrar reglas</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Mostrar las barras de desplazamiento</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Mostrar retículo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Mostrar retículo grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Rejilla</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Escalar rejilla automáticamente</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Rejilla líneas continuas</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Espacio mínimo en la rejilla (px):</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">Escalar rejilla meta automáticamente</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Origin</source>
        <translation>Origen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Mostrar retículo grande</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Auto Zoom</source>
        <translation>Zoom automático</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Margen (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Auto zoom después de la carga</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Ajuste de color</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Auto corregir los colores blanco y negro</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Color lightness threshold:</source>
        <translation>Umbral para la claridad del color:</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Disable for printing</source>
        <translation>Desactivar al imprimir</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Linetypes</source>
        <translation>Tipos de línea</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Usar automáticamente los tipos de línea base de la pantalla de visualización del modelo</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Escalar los patrones de línea basado en el grosor de línea</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Escala del patrón de grosor de 0.00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Visualización y rendimiento</translation>
    </message>
    <message>
        <location line="+229"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Mostrar las entidades con más de N guiones como contínua:</translation>
    </message>
    <message>
        <location line="-82"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Paso ángulo mínimo para la prestación de arcos (grados):</translation>
    </message>
    <message>
        <location line="-134"/>
        <source>Use full resolution for Retina display</source>
        <translation>Utilice la resolución completa de la pantalla Retina</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Antialiasing activado por defecto</translation>
    </message>
    <message>
        <location line="+327"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Número máximo de puntos de referencia muestran:</translation>
    </message>
    <message>
        <location line="-62"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Tiempo de espera para la representación rayado:</translation>
    </message>
    <message>
        <source>Antialiasing on by default</source>
        <translation type="vanished">Antialiasing activado por defecto</translation>
    </message>
    <message>
        <source>Display entities with N dashes as continuous:</source>
        <translation type="obsolete">Mostrar entidades con guiones N como contínua:</translation>
    </message>
    <message>
        <location line="-343"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Usar automáticamente los tipos de línea base de la pantalla de visualización del modelo</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="obsolete">Ajusta automáticamente los tipos de línea</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Rendimiento</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Number of preview entities:</source>
        <translation>Número de entidades previsualizadas:</translation>
    </message>
    <message>
        <source>Text height display threshold (px):</source>
        <translation type="vanished">Mostrar límite para el texto (px):</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Mostrar arcos como las líneas por debajo de este ángulo (grados):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Mostrar límite para el texto:</translation>
    </message>
    <message>
        <location line="+335"/>
        <source>Selection</source>
        <translation>Selección</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Selección persistente</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <source>Show rulers</source>
        <translation type="obsolete">Mostrar reglas</translation>
    </message>
    <message>
        <source>Show scrollbars</source>
        <translation type="obsolete">Mostrar las barras de desplazamiento</translation>
    </message>
    <message>
        <source>Show crosshairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar retículo</translation>
    </message>
    <message>
        <source>Show large crosshairs</source>
        <translation type="obsolete">Mostrar retículo grande</translation>
    </message>
    <message>
        <source>Rulers and Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Los reglas y las barras de desplazamiento</translation>
    </message>
    <message>
        <source>Show Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar las barras de desplazamiento</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translatorcomment>--google--
&amp;Resaltar entidades bajo el cursor
Resaltar entidades bajo el cursor
Coordenadas del mapa en la posición del ratón</translatorcomment>
        <translation type="obsolete">Cursor</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Rejilla</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Escalar rejilla automáticamente</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Rejilla líneas continuas</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Espacio mínimo en la rejilla (px):</translation>
    </message>
    <message>
        <source>Auto Zoom</source>
        <translation type="obsolete">Zoom automático</translation>
    </message>
    <message>
        <source>Color Adjustment</source>
        <translation type="obsolete">Ajuste de color</translation>
    </message>
    <message>
        <source>Prevent white on white / black on black display</source>
        <translation type="obsolete">Auto corregir los colores blanco y negro</translation>
    </message>
    <message>
        <source>Color lightness threshold:</source>
        <translation type="obsolete">Umbral para la claridad del color:</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="obsolete">Rendimiento</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Mostrar límite para el texto:</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translatorcomment>--exact match--
--file: sketch_es.po--
Extensión
Auto zoom</translatorcomment>
        <translation type="obsolete">Nivel de acercamiento</translation>
    </message>
    <message>
        <source>Margin (px):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Margen (px):</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Previsualización</translation>
    </message>
    <message>
        <source>Number of preview entities:</source>
        <translation type="obsolete">Número de entidades previsualizadas:</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crea un nuevo bloque de entidades existentes
Quita la selección a todas las entidades
Deselecciona todas las entidades
Deseleccionar en&amp;tidades cruzadas</translatorcomment>
        <translation type="obsolete">Entidades</translation>
    </message>
    <message>
        <source>Auto correct black and white colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Auto corregir los colores blanco y negro</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation type="obsolete">Selección</translation>
    </message>
    <message>
        <source>Persistent Selection</source>
        <translatorcomment>--google--
Selecciones &amp;persisitentes
Selecciones persisitentes</translatorcomment>
        <translation type="obsolete">Selección persistente</translation>
    </message>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_es.ts--
Ver gráficos</translatorcomment>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
</context>
</TS>
